#
# spec file for package pmount
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define tar_ver 0.9.99-alpha
Name:           pmount
Version:        0.9.99alpha
Release:        3.2
Summary:        Mount arbitrary hotpluggable devices as normal user
License:        GPL-2.0+
Group:          System/Base
Url:            http://alioth.debian.org/projects/pmount
Source0:        http://ftp.debian.org/debian/pool/main/p/%{name}/%{name}_%{tar_ver}.orig.tar.bz2
Source1:        pmount-bash_completion
Source2:        pmount-zsh_completion
Source3:        README.SUSE
Patch0:         %{name}-no_root_install.patch
Patch1:         %{name}-fixes.patch
Patch2:         %{name}-man-plugdev.diff
Patch3:         %{name}-alpha-locale-regex.patch
BuildRequires:  intltool
BuildRequires:  libblkid-devel
BuildRequires:  shadow
Requires(pre):  permissions
Suggests:       cryptsetup
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
pmount ("policy mount") is a wrapper around the standard mount program which
permits normal users to mount removable devices without a matching %{_sysconfdir}/fstab
entry.

pmount also supports encrypted devices which use dm-crypt and have LUKS
metadata. If a LUKS-capable cryptsetup is installed, pmount will use it to
decrypt the device first and mount the mapped unencrypted device instead.

%lang_package

%prep
%setup -q -n %{name}-%{tar_ver}
%patch0 -p1
%patch1
%patch2 -p1
%patch3

%build
export CFLAGS="%{optflags} -fpie"
export LDFLAGS="-pie"
%configure
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}
mkdir %{buildroot}/media
install -Dm0644 %{SOURCE1} %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm0644 %{SOURCE2} %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -Dm0644 %{SOURCE3} .

%pre
getent group plugdev > /dev/null || groupadd -r plugdev

%post
%set_permissions %{_bindir}/pmount
%set_permissions %{_bindir}/pumount

%verifyscript
%verify_permissions -e %{_bindir}/pmount
%verify_permissions -e %{_bindir}/pumount

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README README.devel README.SUSE TODO
%attr(4750 root plugdev) %{_bindir}/%{name}
%attr(4750 root plugdev) %{_bindir}/pumount
%config(noreplace) %{_sysconfdir}/%{name}.allow
%config(noreplace) %{_sysconfdir}/%{name}.conf
%dir /media
%{_mandir}/man1/%{name}.1%{ext_man}
%{_mandir}/man1/pumount.1%{ext_man}
%{_mandir}/man5/%{name}.conf.5%{ext_man}
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/zsh/site-functions/_%{name}

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Mon Mar 13 2017 mpluskal@suse.com
- Create /media directory (boo#1022943)
- Cleanup with spec-cleaner
* Mon Nov 17 2014 tampakrap@opensuse.org
- Fork from Extra/pmount
- Clean up specfile
- patches pmount-no_root_install and pmount-fixes taken from packman Extra/pmount package
- bash completion file taken from the debian package
- zsh completion file taken from https://bugzilla.altlinux.org/show_bug.cgi?id=9501
- add patch regarding localization taken from gentoo
* Thu Aug 16 2012 seife+obs@b1-systems.com
- fix rpmlint error on 12.2+ by adding -fpie to CFLAGS
* Sat Dec  3 2011 pascal.bleser@opensuse.org
- update to 0.9.99-alpha
* Sat Jun 19 2010 detlef@links2linux.de
- new upstream version <0.9.23>
  * fix a security hole (see CVE-2010-2192 for more
  information). Upgrading is seriously recommended.
* Tue May 11 2010 detlef@links2linux.de
- add fix_cryptsetup_rroot.patch
* Fri May  7 2010 detlef@links2linux.de
- new upstream version <0.9.21>
  * now whitelisting ext4.
  * few configure.ac tweaks
  * now, cryptsetup is run by default with ruid = euid = 0 to work
    around a libgcrypt "feature"
  * pulling new translations from Rosetta
* Sat Jan  2 2010 AxelKoellhofer@web.de
- added patch to fix warnings about implcit declarations of functions
- added patch to suppress warning "unknown filesystem ext4dev" on 11.1
- added libblkid-devel to BuildRequires (needed for building in OBS)
* Thu Nov 26 2009 AxelKoellhofer@web.de
- added cryptsetup-rroot.patch from debian upstream
* Fri Nov 13 2009 AxelKoellhofer@web.de
- added bash-completion script (taken from debian sid)
- added ext4 support (adapted patch from debian sid)
- converted sources to bz2
- added rpmlintrc
* Fri Sep 11 2009 detlef@links2linux.de
- new upstream version <0.9.20>
  * fix few typos (in man/pmount.1 and configure.ac)
  * severely discourage lazy unmount
  * switch to errors=remount-ro to avoid massive FS corruption when a
    problem is found
  * allow unmounting of devices which do not exist anymore
  * pulled newer translations from Rosatta
* Thu Mar  5 2009 detlef@links2linux.de
- new upstream version <0.9.19>
  * drop the dependency on libsysfs and also fix failure to recognise
    that a device is removable with newer kernels
  * do realpath expansion on devices whitelisted in /etc/pmount.allow,
    which enables the use of symlinks inside it.
  * fixed few problems in the manual page
  * pulled newer translations from Rosetta
* Fri Oct  3 2008 detlef@links2linux.de
- initial build for PackMan
- cleanup SPEC
* Thu Oct  2 2008 rain_maker@root-forum.org
- modified SPEC to use new group "pmount" instead of "disk" (thx @drcux for advice!)
* Wed Oct  1 2008 rain_maker@root-forum.org
- modified spec based on original file by Tuukka Pasanen
- only member of the group "disk" are allowed to use pmount
- configuration file /etc/pmount.allow will not be overwritten on update
* Tue Oct 23 2007 rpms@ilmi.fi
- Okay this fixes bug that lazy device disapiers before umount
- Gotta get ivman fixed..
* Tue Jul  3 2007 rpms@ilmi.fi
- New version and actually copy binaries :D
* Thu May 24 2007 rpms@ilmi.fi
- Initial build
